IWA Terminal

## Accounts

Track Tokens:

Tag | Address | Type
--- | --- | ---

### Send Transaction

From
To
Amount
Token

## Recent Activity

Time | Chain | From | To | Token | Amount | Value (€) | Status | Hash | Gas (Wei) | Gas (€) | Tags
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

## Olas Services

No Olas services found for this chain.

Account

### Token Swap

Sell exact amount Buy exact amount
Sell
Buy

### Wrap / Unwrap

Wrap xDAI → WXDAI Unwrap WXDAI → xDAI
Amount

### Recent Orders

Date | Order ID | Status | Sell | Buy | Expiring in
--- | --- | --- | --- | --- | ---
Loading orders...

## Node Connectivity

## Create Multisig Safe

Tag Name
Threshold (Signatures needed)
Select Owners
Chains (Select at least one)

## Create EOA Account

Tag Name (optional)

## Confirm Action

## Stake Service

Select a staking contract for this service:

Staking Contract
Loading contracts...

## Create Olas Service

Service Name
Chain
Agent Type
Staking Contract
Loading contracts...

## Fund Service

Send native tokens from master wallet to service accounts:

Agent Amount (xDAI)
Safe Amount (xDAI)

## ⚠️ Terminate Service

This action will:
• Unstake the service (if staked)
• Terminate the service
• Unbond all operators
The service will return to PRE_REGISTRATION state.

## 🔐 Authentication Required

Enter your Web UI password to continue:

Password